@@ -10,13 +10,13 @@ class InvalidManufacturerCode(Exception):
         self.code = code
 
 
-class InvalidMACAddress(Exception):
+class InvalidMACAddressException(Exception):
     def __init__(self, message, code: int = 1):
         super().__init__(message)
         self.code = code
 
 
-class InvalidIPv4Address(Exception):
+class InvalidIPv4AddressException(Exception):
     def __init__(self, message, code: int = 1):
         super().__init__(message)
         self.code = code
