@@ -5,11 +5,11 @@ __author__ = "EONRaider @ keybase.io/eonraider"
 
 import re
 
-from netprotocols.utils.exceptions import InvalidMACAddress
+from netprotocols.utils.exceptions import InvalidMACAddressException
 from netprotocols.utils.validation._base import Validator
 
 mac_regex = re.compile(
-    r"^(?P<manufacturer_id>([\dA-F]{2}[:-]){2}[\dA-F]{2})"
+    r"^(?P<oui>([\dA-F]{2}[:-]){2}[\dA-F]{2})"
     r"[:-]"
     r"(?P<device_id>([\dA-F]{2}[:-]){2}[\dA-F]{2})$",
     flags=re.IGNORECASE,
@@ -24,23 +24,25 @@ class ValidMACAddress(Validator):
     def validate(value: str) -> str:
         try:
             return re.match(mac_regex, value).group()
-        except (TypeError, AttributeError):
+        except (TypeError, AttributeError) as e:
             """
             TypeError: Raised if 'value' is not of type str.
             AttributeError: Raised if 'value' is of type str but doesn't
                 represent a valid MAC address.
             """
-            raise InvalidMACAddress(
-                f"Invalid format or type for MAC address value: {value}"
-            )
+            raise InvalidMACAddressException(
+                f"InvalidMACAddressException: Invalid format or type for MAC "
+                f'address value "{value}"'
+            ) from e
 
 
-def validate_mac_address(mac_address: str) -> bool:
+def validate_mac_addr(mac: str) -> str:
     """Evaluate a string representing an IEEE 802 compliant MAC address.
 
-    :returns: True if valid and False otherwise.
+    :returns: The supplied string if it corresponds to a valid MAC
+        address.
+
+    :raises InvalidMACAddressException: If the supplied string does not
+        correspond to a valid MAC address.
     """
-    try:
-        return bool(ValidMACAddress.validate(mac_address))
-    except InvalidMACAddress:
-        return False
+    return ValidMACAddress.validate(mac)
